@@ -175,6 +175,8 @@ public class AJD implements Day {
 		this( new Date() );
 	}
 
+	private static final BigDecimal DATE_FIX = new BigDecimal( "0.000000000000000001" );
+
 	/**
 	 * コンストラクタ。引数の日時を表すインスタンスを生成します。
 	 * @param date 日時。
@@ -233,6 +235,11 @@ public class AJD implements Day {
 
 		long s = cut( tmp.multiply( J86400 ).add( FIX05 ) );
 		hour = (int)( s / 3600 );
+		if ( hour >= 24 ) {
+			ajd = ajd.add( DATE_FIX );
+			set( offset );
+			return;
+		}
 		min = (int)( ( s % 3600 ) / 60 );
 		sec = (int)( s % 60 );
 	}
@@ -397,7 +404,7 @@ public class AJD implements Day {
 	 * @return Date型。
 	 */
 	public java.sql.Date toDate() {
-		return new java.sql.Date( getTime() );
+		return new java.sql.Date( trim().getTime() );
 	}
 
 	/**
@@ -405,7 +412,11 @@ public class AJD implements Day {
 	 * @return Time型。
 	 */
 	public java.sql.Time toTime() {
-		return new java.sql.Time( getTime() );
+		try {
+			return new java.sql.Time( new AJD( 1970, 1, 1, getHour(), getMinute(), getSecond() ).getTime() );
+		}
+		catch( AJDException e ) {}
+		return null;
 	}
 
 	/**
